aboutsummaryrefslogtreecommitdiff
path: root/include/llvm/CodeGen/MachineInstr.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/CodeGen/MachineInstr.h')
-rw-r--r--include/llvm/CodeGen/MachineInstr.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/llvm/CodeGen/MachineInstr.h b/include/llvm/CodeGen/MachineInstr.h
index 7c8fe880bb..5450e839db 100644
--- a/include/llvm/CodeGen/MachineInstr.h
+++ b/include/llvm/CodeGen/MachineInstr.h
@@ -68,9 +68,9 @@ public:
const MachineBasicBlock* getParent() const { return Parent; }
MachineBasicBlock* getParent() { return Parent; }
/// getInstrDescriptor - Returns the target instruction descriptor of this
/// MachineInstr.
- const TargetInstrDescriptor *getInstrDescriptor() const { return TID; }
+ const TargetInstrDescriptor *getDesc() const { return TID; }
/// getOpcode - Returns the opcode of this MachineInstr.
///
@@ -68,9 +68,9 @@ public:
const MachineBasicBlock* getParent() const { return Parent; }
MachineBasicBlock* getParent() { return Parent; }
- /// getInstrDescriptor - Returns the target instruction descriptor of this
+ /// getDesc - Returns the target instruction descriptor of this
/// MachineInstr.